operation property

  1. @protected
  2. @visibleForTesting
Object? operation
getter/setter pairinherited

Keeps track of the current operation. If the operation changes during its execution, the operation is cancelled.

Instead of using this property directly, use fetchNextPage, refresh, or cancel. If you are extending this class, check and set this property before and after the fetch operation.

Implementation

@protected
@visibleForTesting
Object? operation;