BasePagingController<T, P extends BasePagination<T> > class
A controller for a paged widget.
If you modify the itemList, error or nextPageKey properties, the paged widget will be notified and will update itself appropriately.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
PagingState< int, T> > - PagingController<
int, T> - BasePagingController
Constructors
- BasePagingController({dynamic firstPageKey = 0, dynamic invisibleItemsThreshold = 5})
- Creates an BasePagingController
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- operation ↔ Object?
-
Keeps track of the current operation.
If the operation changes during its execution, the operation is cancelled.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
↔ PagingState<
int, T> -
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
cancel(
) → void -
Cancels the current fetch operation.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
fetchNextPage(
) → void -
Fetches the next page.
inherited
-
fetchPage(
Future< P> onLoadMore) → Future<void> - Call when page scroll to end
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onError(
Object exception) → void - call onError when error
-
onRefresh(
) → Future< void> - call onError when error
-
onSuccess(
P pagination) → void - call onSuccess when success
-
refresh(
) → void -
Restarts the pagination process.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trigger(
{dynamic onLoadMore, dynamic onStatusChange}) → void - call trigger when initState
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited